/*
 * Copyright Bigeon Emmanuel (2014)
 *
 * emmanuel@bigeon.fr
 *
 * This software is a computer program whose purpose is to
 * provide a generic framework for console applications.
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
/**
 * gclc:net.bigeon.gclc.command.HelpExecutorTest.java
 * Created on: Nov 19, 2016
 */
package net.bigeon.gclc.command;

/*-
 * #%L
 * Generic Command Ligne console
 * %%
 * Copyright (C) 2014 - 2018 bigeon.fr
 * %%
 * This software is governed by the CeCILL  license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 * #L%
 */
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.fail;

import java.io.IOException;

import org.junit.Test;

import net.bigeon.gclc.command.base.HelpExecutor;
import net.bigeon.gclc.command.base.MockCommand;
import net.bigeon.gclc.exception.CommandRunException;
import net.bigeon.gclc.manager.ConsoleInput;
import net.bigeon.gclc.manager.ConsoleOutput;
import net.bigeon.gclc.utils.PipedConsoleOutput;

/**
 * <p>
 * TODO
 *
 * @author Emmanuel Bigeon */
public class HelpExecutorTest {

    /** Test method for
     * {@link net.bigeon.gclc.command.base.HelpExecutor#execute(ConsoleOutput, ConsoleInput, String...)}.
     *
     * @throws CommandRunException if the test failed
     * @throws IOException if the test failed */
    @Test
    public final void testExecute() throws CommandRunException, IOException {
        final PipedConsoleOutput test = new PipedConsoleOutput();
        final HelpExecutor help = new HelpExecutor("?", new Command("mock") {

            @Override
            public void execute(final ConsoleOutput out, final ConsoleInput in,
                    final String... args) throws CommandRunException {
                //
            }

            @Override
            public String tip() {
                return "";
            }

            @Override
            protected String usageDetail() {
                return null;
            }

        });

        help.execute(test, null);
        test.close();

        try {
            help.execute(test, null);
            fail("manager closed shall provoke failure of help command execution");
        } catch (final Exception e) {
            // ok
        }
    }

    /** Test method for {@link net.bigeon.gclc.command.base.HelpExecutor#tip()}.
     *
     * @throws IOException if the test failed */
    @Test
    public final void testTip() throws IOException {
        try (PipedConsoleOutput test = new PipedConsoleOutput()) {
            final HelpExecutor help = new HelpExecutor("?", new MockCommand("mock"));
            assertNotNull("Tip should be provided", help.tip());
            help.help(test);
        }
        try (PipedConsoleOutput test = new PipedConsoleOutput()) {
            final HelpExecutor help = new HelpExecutor("?",
                    new SubedCommand("sub", new MockCommand("mock")));
            help.tip();
            help.help(test);
        }
    }

}
